pub fn dc_tree_generation(pipeline: &mut PipelineData<'_>) -> DCFileExpand description
Last step of the DC parser pipeline. Generates the final immutable DC element tree data structure for usage by Donet clients and Donet server services.
pub fn dc_tree_generation(pipeline: &mut PipelineData<'_>) -> DCFileLast step of the DC parser pipeline. Generates the final immutable DC element tree data structure for usage by Donet clients and Donet server services.